==> libopenshot-audio-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/all_14.js <==
var searchData=
[
  ['uncompressedsize_0',['uncompressedSize',['../classjuce_1_1ZipFile.html#a57bb2624bcd7f6f4023c144c877c9027',1,'juce::ZipFile::ZipEntry']]],
  ['uncompressentry_1',['uncompressEntry',['../classjuce_1_1ZipFile.html#a9a8dab46fffdf228a4e987f32452c30d',1,'juce::ZipFile']]],
  ['uncompressto_2',['uncompressTo',['../classjuce_1_1ZipFile.html#a0ff0791b2847ef11e5e1e012956cbc69',1,'juce::ZipFile']]],
  ['undefined_3',['undefined',['../classjuce_1_1var.html#a07ddc05d7a4417076cb8170cf574060d',1,'juce::var']]],
  ['undo_4',['undo',['../classjuce_1_1UndoManager.html#a31b32005c03d2b3787af5c57f57895ab',1,'juce::UndoManager::undo()'],['../classjuce_1_1UndoableAction.html#a15140dbf7f21e46c0d456f9c9ef3b8e1',1,'juce::UndoableAction::undo()']]],
  ['undoableaction_5',['UndoableAction',['../classjuce_1_1UndoableAction.html',1,'juce::UndoableAction'],['../classjuce_1_1UndoableAction.html#a1c05ffce16a36c22b15a7ce575edc761',1,'juce::UndoableAction::UndoableAction()']]],
  ['undocurrenttransactiononly_6',['undoCurrentTransactionOnly',['../classjuce_1_1UndoManager.html#a8814e4f84acce0f2e46eb346c20d1476',1,'juce::UndoManager']]],
  ['undomanager_7',['UndoManager',['../classjuce_1_1UndoManager.html',1,'juce::UndoManager'],['../classjuce_1_1UndoManager.html#aa2f80bc9ec027a2e796c10795728a094',1,'juce::UndoManager::UndoManager()']]],
  ['unhandledexception_8',['unhandledException',['../classjuce_1_1JUCEApplicationBase.html#adda8cfe8a8023ac4019d1728c7526169',1,'juce::JUCEApplicationBase']]],
  ['unittest_9',['UnitTest',['../classjuce_1_1UnitTest.html',1,'juce::UnitTest'],['../classjuce_1_1UnitTest.html#a75f52ae0b453f16745b8739a96f961ad',1,'juce::UnitTest::UnitTest()']]],
  ['unittestname_10',['unitTestName',['../classjuce_1_1UnitTestRunner.html#ab677c0bbe159375d828d1e6ba3f81771',1,'juce::UnitTestRunner::TestResult']]],
  ['unittestrunner_11',['UnitTestRunner',['../classjuce_1_1UnitTestRunner.html',1,'juce']]],
  ['unknown_12',['unknown',['../classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a4cdb70380fe60035dcb5dfecbfd13129',1,'juce::AudioChannelSet']]],
  ['unquoted_13',['unquoted',['../classjuce_1_1String.html#ab073078c5a4055d1bbdd808803892049',1,'juce::String']]],
  ['unsignedtypewithsize_14',['UnsignedTypeWithSize',['../namespacejuce_1_1TypeHelpers.html#structjuce_1_1TypeHelpers_1_1UnsignedTypeWithSize',1,'juce::TypeHelpers']]],
  ['updatematchedpairs_15',['updateMatchedPairs',['../classjuce_1_1MidiMessageSequence.html#a42c636f2d5706e772503f52b348808c0',1,'juce::MidiMessageSequence']]],
  ['updatesymmetricfrequencydomaindata_16',['updateSymmetricFrequencyDomainData',['../structjuce_1_1dsp_1_1ConvolutionEngine.html#a005320135f9acda87be5f8556dbaaef2',1,'juce::dsp::ConvolutionEngine']]],
  ['uptofirstoccurrenceof_17',['upToFirstOccurrenceOf',['../classjuce_1_1String.html#a104293243d3705433aba984bfe16c483',1,'juce::String']]],
  ['uptolastoccurrenceof_18',['upToLastOccurrenceOf',['../classjuce_1_1String.html#aaaed20ecc7e18b21e13e70f9184f4345',1,'juce::String']]],
  ['url_19',['URL',['../classjuce_1_1URL.html',1,'juce::URL'],['../classjuce_1_1URL.html#aeb5801565a2084bc055d8b98b8cdfe97',1,'juce::URL::URL()'],['../classjuce_1_1URL.html#ad357b3ca63a23841b23ae8311830cfd1',1,'juce::URL::URL(const String &amp;url)'],['../classjuce_1_1URL.html#a7c7b9e47f4886610445c58775e6c5e99',1,'juce::URL::URL(File)']]],
  ['urlinputsource_20',['URLInputSource',['../classjuce_1_1URLInputSource.html',1,'juce::URLInputSource'],['../classjuce_1_1URLInputSource.html#aa575ed97cbb4d8d4e90d98a06b96517b',1,'juce::URLInputSource::URLInputSource(const URL &amp;url)'],['../classjuce_1_1URLInputSource.html#a047e8a19bfbc72890bd9a3890884d19a',1,'juce::URLInputSource::URLInputSource(URL &amp;&amp;url)']]],
  ['usedefaultinputchannels_21',['useDefaultInputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#a21edcaa3d650dbb62205c375ef36f8cb',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['usedefaultoutputchannels_22',['useDefaultOutputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ae1cc4ca6e512d83527f0e80863438ec7',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['usehiddenfile_23',['useHiddenFile',['../classjuce_1_1TemporaryFile.html#a09bdd60ad81f00992f2b59eb2a0519e3afb9942ba2271eafe51c70d0f4a708a91',1,'juce::TemporaryFile']]],
  ['userapplicationdatadirectory_24',['userApplicationDataDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a8125a563332d94c32da9ccf24c4e7c40',1,'juce::File']]],
  ['userdesktopdirectory_25',['userDesktopDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317acaa7f7234f7eee33b5d5dab09102da13',1,'juce::File']]],
  ['userdocumentsdirectory_26',['userDocumentsDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a26cb3c4cf49780b81936593ca6bb0c1d',1,'juce::File']]],
  ['userhomedirectory_27',['userHomeDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317afc7a0751112d5d2a2b7a5d139e65b967',1,'juce::File']]],
  ['usermoviesdirectory_28',['userMoviesDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a0e1d2f77f2ddcaee9293c4c8bdb67229',1,'juce::File']]],
  ['usermusicdirectory_29',['userMusicDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a1952809f4ffafbba9e37551598c2ae3d',1,'juce::File']]],
  ['userpicturesdirectory_30',['userPicturesDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317ab0fa76844b8b179af2d7e32decfc7ccd',1,'juce::File']]],
  ['usesanysymbols_31',['usesAnySymbols',['../classjuce_1_1Expression.html#a5cd72c796ed5cf67dfc367d69227fd56',1,'juce::Expression']]],
  ['usesfloatingpointdata_32',['usesFloatingPointData',['../classjuce_1_1AudioFormatReader.html#a07b44f6fb2aa02226943244ffc36b0ed',1,'juce::AudioFormatReader::usesFloatingPointData()'],['../classjuce_1_1AudioFormatWriter.html#a141cb99ea9e4a9c576600eab06893c38',1,'juce::AudioFormatWriter::usesFloatingPointData()']]],
  ['usesseparateinputandoutputblocks_33',['usesSeparateInputAndOutputBlocks',['../structjuce_1_1dsp_1_1ProcessContextReplacing.html#a50a6fdf62bc01b527cdc162d50cf839f',1,'juce::dsp::ProcessContextReplacing::usesSeparateInputAndOutputBlocks()'],['../structjuce_1_1dsp_1_1ProcessContextNonReplacing.html#a080f625172b8a62fc65e410b3fa93815',1,'juce::dsp::ProcessContextNonReplacing::usesSeparateInputAndOutputBlocks()']]],
  ['usetimeslice_34',['useTimeSlice',['../classjuce_1_1TimeSliceClient.html#a41adb2ec9d40c457fa7f05769ef6fbfa',1,'juce::TimeSliceClient']]],
  ['uuid_35',['Uuid',['../classjuce_1_1Uuid.html',1,'juce::Uuid'],['../classjuce_1_1Uuid.html#a19e5e6bdfdd63cf9148eff3b03c93c4a',1,'juce::Uuid::Uuid()'],['../classjuce_1_1Uuid.html#ae2f7dd92d4db1ce52c9930917397f8ab',1,'juce::Uuid::Uuid(const Uuid &amp;) noexcept'],['../classjuce_1_1Uuid.html#a853c61bb849f77e10bcd4c3d6e63f3e1',1,'juce::Uuid::Uuid(const String &amp;uuidString)'],['../classjuce_1_1Uuid.html#a16b46a60cf7ed608caefc215637fd5ec',1,'juce::Uuid::Uuid(const uint8 *rawData) noexcept']]]
];

==> libopenshot-audio-docs-0.3.3-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/all_14.js <==
var searchData=
[
  ['uncompressedsize_0',['uncompressedSize',['../classjuce_1_1ZipFile.html#a57bb2624bcd7f6f4023c144c877c9027',1,'juce::ZipFile::ZipEntry']]],
  ['uncompressentry_1',['uncompressEntry',['../classjuce_1_1ZipFile.html#a9a8dab46fffdf228a4e987f32452c30d',1,'juce::ZipFile']]],
  ['uncompressto_2',['uncompressTo',['../classjuce_1_1ZipFile.html#a0ff0791b2847ef11e5e1e012956cbc69',1,'juce::ZipFile']]],
  ['undefined_3',['undefined',['../classjuce_1_1var.html#a07ddc05d7a4417076cb8170cf574060d',1,'juce::var']]],
  ['undo_4',['undo',['../classjuce_1_1UndoableAction.html#a15140dbf7f21e46c0d456f9c9ef3b8e1',1,'juce::UndoableAction::undo()'],['../classjuce_1_1UndoManager.html#a31b32005c03d2b3787af5c57f57895ab',1,'juce::UndoManager::undo()']]],
  ['undoableaction_5',['UndoableAction',['../classjuce_1_1UndoableAction.html',1,'juce::UndoableAction'],['../classjuce_1_1UndoableAction.html#a1c05ffce16a36c22b15a7ce575edc761',1,'juce::UndoableAction::UndoableAction()']]],
  ['undocurrenttransactiononly_6',['undoCurrentTransactionOnly',['../classjuce_1_1UndoManager.html#a8814e4f84acce0f2e46eb346c20d1476',1,'juce::UndoManager']]],
  ['undomanager_7',['UndoManager',['../classjuce_1_1UndoManager.html',1,'juce::UndoManager'],['../classjuce_1_1UndoManager.html#aa2f80bc9ec027a2e796c10795728a094',1,'juce::UndoManager::UndoManager()']]],
  ['unhandledexception_8',['unhandledException',['../classjuce_1_1JUCEApplicationBase.html#adda8cfe8a8023ac4019d1728c7526169',1,'juce::JUCEApplicationBase']]],
  ['unittest_9',['UnitTest',['../classjuce_1_1UnitTest.html',1,'juce::UnitTest'],['../classjuce_1_1UnitTest.html#a75f52ae0b453f16745b8739a96f961ad',1,'juce::UnitTest::UnitTest()']]],
  ['unittestname_10',['unitTestName',['../classjuce_1_1UnitTestRunner.html#ab677c0bbe159375d828d1e6ba3f81771',1,'juce::UnitTestRunner::TestResult']]],
  ['unittestrunner_11',['UnitTestRunner',['../classjuce_1_1UnitTestRunner.html',1,'juce']]],
  ['unknown_12',['unknown',['../classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a4cdb70380fe60035dcb5dfecbfd13129',1,'juce::AudioChannelSet']]],
  ['unquoted_13',['unquoted',['../classjuce_1_1String.html#ab073078c5a4055d1bbdd808803892049',1,'juce::String']]],
  ['unsignedtypewithsize_14',['UnsignedTypeWithSize',['../namespacejuce_1_1TypeHelpers.html#structjuce_1_1TypeHelpers_1_1UnsignedTypeWithSize',1,'juce::TypeHelpers']]],
  ['updatematchedpairs_15',['updateMatchedPairs',['../classjuce_1_1MidiMessageSequence.html#a42c636f2d5706e772503f52b348808c0',1,'juce::MidiMessageSequence']]],
  ['updatesymmetricfrequencydomaindata_16',['updateSymmetricFrequencyDomainData',['../structjuce_1_1dsp_1_1ConvolutionEngine.html#a005320135f9acda87be5f8556dbaaef2',1,'juce::dsp::ConvolutionEngine']]],
  ['uptofirstoccurrenceof_17',['upToFirstOccurrenceOf',['../classjuce_1_1String.html#a104293243d3705433aba984bfe16c483',1,'juce::String']]],
  ['uptolastoccurrenceof_18',['upToLastOccurrenceOf',['../classjuce_1_1String.html#aaaed20ecc7e18b21e13e70f9184f4345',1,'juce::String']]],
  ['url_19',['URL',['../classjuce_1_1URL.html',1,'juce::URL'],['../classjuce_1_1URL.html#aeb5801565a2084bc055d8b98b8cdfe97',1,'juce::URL::URL()'],['../classjuce_1_1URL.html#ad357b3ca63a23841b23ae8311830cfd1',1,'juce::URL::URL(const String &amp;url)'],['../classjuce_1_1URL.html#a7c7b9e47f4886610445c58775e6c5e99',1,'juce::URL::URL(File)']]],
  ['urlinputsource_20',['URLInputSource',['../classjuce_1_1URLInputSource.html',1,'juce::URLInputSource'],['../classjuce_1_1URLInputSource.html#aa575ed97cbb4d8d4e90d98a06b96517b',1,'juce::URLInputSource::URLInputSource(const URL &amp;url)'],['../classjuce_1_1URLInputSource.html#a047e8a19bfbc72890bd9a3890884d19a',1,'juce::URLInputSource::URLInputSource(URL &amp;&amp;url)']]],
  ['usedefaultinputchannels_21',['useDefaultInputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#a21edcaa3d650dbb62205c375ef36f8cb',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['usedefaultoutputchannels_22',['useDefaultOutputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ae1cc4ca6e512d83527f0e80863438ec7',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['usehiddenfile_23',['useHiddenFile',['../classjuce_1_1TemporaryFile.html#a09bdd60ad81f00992f2b59eb2a0519e3afb9942ba2271eafe51c70d0f4a708a91',1,'juce::TemporaryFile']]],
  ['userapplicationdatadirectory_24',['userApplicationDataDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a8125a563332d94c32da9ccf24c4e7c40',1,'juce::File']]],
  ['userdesktopdirectory_25',['userDesktopDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317acaa7f7234f7eee33b5d5dab09102da13',1,'juce::File']]],
  ['userdocumentsdirectory_26',['userDocumentsDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a26cb3c4cf49780b81936593ca6bb0c1d',1,'juce::File']]],
  ['userhomedirectory_27',['userHomeDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317afc7a0751112d5d2a2b7a5d139e65b967',1,'juce::File']]],
  ['usermoviesdirectory_28',['userMoviesDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a0e1d2f77f2ddcaee9293c4c8bdb67229',1,'juce::File']]],
  ['usermusicdirectory_29',['userMusicDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317a1952809f4ffafbba9e37551598c2ae3d',1,'juce::File']]],
  ['userpicturesdirectory_30',['userPicturesDirectory',['../classjuce_1_1File.html#a6efe0648697f59af5952171d5e7b0317ab0fa76844b8b179af2d7e32decfc7ccd',1,'juce::File']]],
  ['usesanysymbols_31',['usesAnySymbols',['../classjuce_1_1Expression.html#a5cd72c796ed5cf67dfc367d69227fd56',1,'juce::Expression']]],
  ['usesfloatingpointdata_32',['usesFloatingPointData',['../classjuce_1_1AudioFormatReader.html#a07b44f6fb2aa02226943244ffc36b0ed',1,'juce::AudioFormatReader::usesFloatingPointData'],['../classjuce_1_1AudioFormatWriter.html#a141cb99ea9e4a9c576600eab06893c38',1,'juce::AudioFormatWriter::usesFloatingPointData']]],
  ['usesseparateinputandoutputblocks_33',['usesSeparateInputAndOutputBlocks',['../structjuce_1_1dsp_1_1ProcessContextReplacing.html#a50a6fdf62bc01b527cdc162d50cf839f',1,'juce::dsp::ProcessContextReplacing::usesSeparateInputAndOutputBlocks()'],['../structjuce_1_1dsp_1_1ProcessContextNonReplacing.html#a080f625172b8a62fc65e410b3fa93815',1,'juce::dsp::ProcessContextNonReplacing::usesSeparateInputAndOutputBlocks()']]],
  ['usetimeslice_34',['useTimeSlice',['../classjuce_1_1TimeSliceClient.html#a41adb2ec9d40c457fa7f05769ef6fbfa',1,'juce::TimeSliceClient']]],
  ['uuid_35',['Uuid',['../classjuce_1_1Uuid.html',1,'juce::Uuid'],['../classjuce_1_1Uuid.html#a19e5e6bdfdd63cf9148eff3b03c93c4a',1,'juce::Uuid::Uuid()'],['../classjuce_1_1Uuid.html#ae2f7dd92d4db1ce52c9930917397f8ab',1,'juce::Uuid::Uuid(const Uuid &amp;) noexcept'],['../classjuce_1_1Uuid.html#a853c61bb849f77e10bcd4c3d6e63f3e1',1,'juce::Uuid::Uuid(const String &amp;uuidString)'],['../classjuce_1_1Uuid.html#a16b46a60cf7ed608caefc215637fd5ec',1,'juce::Uuid::Uuid(const uint8 *rawData) noexcept']]]
];
